.. _reporting-bugs:

**************************
Reporting Bugs in Mini-AMF
**************************

Bug reports should be submitted to the `Github issue tracker
<https://github.com/zackw/mini-amf/issues>`_.

.. seealso::

   `How to Report Bugs Effectively <http://www-mice.cs.ucl.ac.uk/multimedia/software/documentation/ReportingBugs.html>`_
      Article which goes into some detail about how to create a useful
      bug report.  This describes what kind of information is useful
      and why it is useful.

   `Bug Writing Guidelines <https://developer.mozilla.org/en/Bug_writing_guidelines>`_
      Information about writing a good bug report.  Some of this is
      specific to the Mozilla project, but describes general good
      practices.
